ml4gw.waveforms package
=======================

Submodules
----------

ml4gw.waveforms.generator module
--------------------------------

.. automodule:: ml4gw.waveforms.generator
   :members:
   :undoc-members:
   :show-inheritance:

ml4gw.waveforms.phenom\_d module
--------------------------------

.. automodule:: ml4gw.waveforms.phenom_d
   :members:
   :undoc-members:
   :show-inheritance:

ml4gw.waveforms.phenom\_d\_data module
--------------------------------------

.. automodule:: ml4gw.waveforms.phenom_d_data
   :members:
   :undoc-members:
   :show-inheritance:

ml4gw.waveforms.sine\_gaussian module
-------------------------------------

.. automodule:: ml4gw.waveforms.sine_gaussian
   :members:
   :undoc-members:
   :show-inheritance:

ml4gw.waveforms.taylorf2 module
-------------------------------

.. automodule:: ml4gw.waveforms.taylorf2
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: ml4gw.waveforms
   :members:
   :undoc-members:
   :show-inheritance:
